@@ -33,6 +33,8 @@ use Carp ( 'croak' );
 use XML::Simple;
 use Class::Struct;
 
+$Net::UPS::Package::VERSION = '0.02';
+
 struct(
     id                  => '$',
     packaging_type      => '$',
@@ -130,24 +132,60 @@ Convenience method. Return value indicates if the package is oversized, and if s
 
 =cut
 
+# Scoob correction Feb 26th 2006 / cpan@pickledbrain.com
+#
+# Definitions of oversize categories:
+#   http://www.ups.com/content/us/en/resources/prepare/oversize.html
+#
+# Length and Girth: Length + 2x Width + 2x Height
+# Where Length is the longuest side of pkg rounded to nearest inch.
+# And Girth is: 2x Width + 2x Height) (round width & height to nearest inch)
+#
+# Also as described in: 
+#    http://www.ups.com/content/us/en/resources/prepare/guidelines/index.html
+# - Packages can be up to 150 lbs (70 kg)
+# - Packages can be up to 165 inches (419 cm) in length and girth combined
+# - Packages can be up to 108 inches (270 cm) in length
+# - Packages that weigh more than 70 lbs (31.5 kg, 25 kg within the EU) require a special heavy-package label
+# - Oversize packages and packages with a large size-to-weight ratio require special pricing 
+#   and dimensional weight calculations
+#
+# Understand that "Oversize" OS[123] package is a rating to compensate for
+# a package that is very large but weights very little.  UPS charges for
+# a "billing weight" that is larger than the actual weight for OS packages.
+# So for a package to be OS1 is must be 84 < size < 108  *AND* weight < 30lbs 
+# If a package is size 104" and has weight: 33lbs, is is NOT OS1 (because it is
+# heavy enough that UPS will be fairly compensated by charging for weight only.
+#
+###
 sub is_oversized {
     my $self = shift;
 
     unless ( $self->width && $self->height && $self->length && $self->weight) {
         return 0;
     }
-    my $girth = $self->length + $self->width + $self->height;
-    return 0 if ( $girth < 84 );
-    if ( ($girth < 108) && ($self->weight < 30) ) {
-        return 1;
+
+    my @sides = sort ($self->length, $self->width, $self->height);
+    my $len = pop(@sides);  # Get longest side
+    my $girth = ((2 * $sides[0]) + (2 * $sides[1]));
+    my $size = $len + $girth;
+    
+    if (($len > 108) || ($self->weight > 150) || ($size > 165)) {
+	croak "Such package size/weight is not supported";  
     }
-    if ( ($girth < 130) && ($self->weight < 70) ) {
-        return 2;
+
+    return 0 if ( $size <= 84 );                   # Below OS1
+    if ($size <= 108) {                            # OS1 pgk is billed for 30lbs 
+	return (($self->weight < 30) ? 1 : 0);     # Not OS1 if weight > 30lbs
     }
-    if ( ($girth < 165) && ($self->weight < 90) ) {
+    if ($size <= 130) {                            # OS2 pgk is billed for 70lbs 
+	return (($self->weight < 70) ? 2 : 0);     # Not OS2 if weight > 70lbs
+    }
+    if ($size <= 165) {                            # OS3 pgk is billed for 90lbs 
+	return (($self->weight < 90) ? 3 : 0);     # Not OS3 if weight > 90lbs
         return 3;
     }
-    croak "Such package size/weight is not supported";
+
 }
 
 
@@ -193,3 +231,4 @@ __END__
 For support and licensing information refer to L<Net::UPS|Net::UPS/"AUTHOR">
 
 =cut
+
